@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2013 ECMWF.
+ * Copyright 2005-2014 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -10,7 +10,8 @@
 
 #include "grib_api.h"
 
-int main(int argc, char* argv[]) {
+int main(int argc, char* argv[])
+{
 	FILE* f;
 	int err=0;
 	char infile[]="../../data/reduced_gaussian_model_level.grib1";
