@@ -21,12 +21,13 @@
 
 #include "grib_api.h"  
 
-void usage(char* prog) {
+void usage(const char* prog) {
   printf("Usage: %s grib_file\n",prog);
   exit(1);
 }
 
-int main(int argc, char** argv) {
+int main(int argc, char** argv)
+{
   FILE* in = NULL;
   int err = 0;
   double lat,lon,value,missingValue=0;
@@ -40,7 +41,7 @@ int main(int argc, char** argv) {
   
   if (argc != 2) usage(argv[0]);
 
-  filename=strdup(argv[1]);
+    filename=argv[1];
 
   in = fopen(filename,"r");
   if(!in) {
@@ -79,7 +80,6 @@ int main(int argc, char** argv) {
     grib_handle_delete(h);            
   }
 
-
   fclose(in);
 
   return 0;
