@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2013 ECMWF.
+ * Copyright 2005-2014 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -9,12 +9,9 @@
  */
 
 /*
- * C Implementation: set
- *
- * Description: how to set key values.
- *
- *
+ * C Implementation: mars_param
  *
+ * Description: how to query MARS params
  *
  */
 #include <stdio.h>
@@ -22,7 +19,8 @@
 
 #include "grib_api.h"
 
-int main(int argc, char** argv) {
+int main(int argc, char** argv)
+{
 	grib_string_list* list;
 	grib_string_list* list2;
 
