@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright 2005-2013 ECMWF.
+# Copyright 2005-2014 ECMWF.
 #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -11,9 +11,15 @@
 
 if [ ! -f "${data_dir}/multi.grib2" ] 
 then
-  echo SKIP: $0
-  exit
+  echo "SKIP test 1: $0"
+else
+  ${examples_dir}multi > /dev/null
 fi
-${examples_dir}multi > /dev/null
 
+if [ ! -f "${data_dir}/multi_created.grib2" ]
+then
+  echo "SKIP test 2: $0"
+else
+  ${examples_dir}multi2 > /dev/null
+fi
 
