@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright 2005-2013 ECMWF.
+# Copyright 2005-2014 ECMWF.
 #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -11,9 +11,9 @@
 
 # if an index file does not exist then
 # create index and save to disk
-${examples_dir}index > index_f90.out
+${examples_dir}f_index > index_f90.out
 diff index_f90.out ${data_dir}/index_f90.ok
 
 # if an index file exists then load the index from it
-${examples_dir}index > index_f90.out
+${examples_dir}f_index > index_f90.out
 diff index_f90.out ${data_dir}/index_f90.ok
