@@ -6,7 +6,7 @@ TEMP1=temp1
 TEMP2=temp2
 
 $PYTHON print_data.py 2> $TEMP1 > $TEMP1
-./print_data ../../data/regular_latlon_surface.grib1 2> $TEMP2 > $TEMP2
+./p_print_data ../../data/regular_latlon_surface.grib1 2> $TEMP2 > $TEMP2
 
 diff $TEMP1 $TEMP2
 rm $TEMP1 $TEMP2 || true
