@@ -1,17 +1,26 @@
+/*
+ * Copyright 2005-2014 ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
+ * In applying this licence, ECMWF does not waive the privileges and immunities granted to it by
+ * virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.
+ */
 
 /* grib_fortran.c */
-int grib_f_read_any_headers_only_from_file_(int *fid, char *buffer, int *nbytes);
-int grib_f_read_any_headers_only_from_file__(int *fid, char *buffer, int *nbytes);
-int grib_f_read_any_headers_only_from_file(int *fid, char *buffer, int *nbytes);
-int grib_f_read_any_from_file_(int *fid, char *buffer, int *nbytes);
-int grib_f_read_any_from_file__(int *fid, char *buffer, int *nbytes);
-int grib_f_read_any_from_file(int *fid, char *buffer, int *nbytes);
-int grib_f_write_file_(int *fid, char *buffer, int *nbytes);
-int grib_f_write_file__(int *fid, char *buffer, int *nbytes);
-int grib_f_write_file(int *fid, char *buffer, int *nbytes);
-int grib_f_read_file_(int *fid, char *buffer, int *nbytes);
-int grib_f_read_file__(int *fid, char *buffer, int *nbytes);
-int grib_f_read_file(int *fid, char *buffer, int *nbytes);
+int grib_f_read_any_headers_only_from_file_(int *fid, char *buffer, size_t *nbytes);
+int grib_f_read_any_headers_only_from_file__(int *fid, char *buffer, size_t *nbytes);
+int grib_f_read_any_headers_only_from_file(int *fid, char *buffer, size_t *nbytes);
+int grib_f_read_any_from_file_(int *fid, char *buffer, size_t *nbytes);
+int grib_f_read_any_from_file__(int *fid, char *buffer, size_t *nbytes);
+int grib_f_read_any_from_file(int *fid, char *buffer, size_t *nbytes);
+int grib_f_write_file_(int *fid, char *buffer, size_t *nbytes);
+int grib_f_write_file__(int *fid, char *buffer, size_t *nbytes);
+int grib_f_write_file(int *fid, char *buffer, size_t *nbytes);
+int grib_f_read_file_(int *fid, char *buffer, size_t *nbytes);
+int grib_f_read_file__(int *fid, char *buffer, size_t *nbytes);
+int grib_f_read_file(int *fid, char *buffer, size_t *nbytes);
 int grib_f_open_file_(int *fid, char *name, char *op, int lname, int lop);
 int grib_f_open_file__(int *fid, char *name, char *op, int lname, int lop);
 int grib_f_open_file(int *fid, char *name, char *op, int lname, int lop);
@@ -160,6 +169,9 @@ int grib_f_get_int_array(int *gid, char *key, int *val, int *size, int len);
 int grib_f_get_long_array_(int *gid, char *key, long *val, int *size, int len);
 int grib_f_get_long_array__(int *gid, char *key, long *val, int *size, int len);
 int grib_f_get_long_array(int *gid, char *key, long *val, int *size, int len);
+int grib_f_get_byte_array_(int* gid, char* key, unsigned char *val, int* size, int len, int lenv);
+int grib_f_get_byte_array__(int* gid, char* key, unsigned char *val, int* size, int len, int lenv);
+int grib_f_get_byte_array(int* gid, char* key, unsigned char *val, int* size, int len, int lenv);
 int grib_f_index_get_string_(int *gid, char *key, char *val, int *eachsize, int *size, int len);
 int grib_f_index_get_string__(int *gid, char *key, char *val, int *eachsize, int *size, int len);
 int grib_f_index_get_string(int *gid, char *key, char *val, int *eachsize, int *size, int len);
@@ -178,6 +190,9 @@ int grib_f_set_int_array(int *gid, char *key, int *val, int *size, int len);
 int grib_f_set_long_array_(int *gid, char *key, long *val, int *size, int len);
 int grib_f_set_long_array__(int *gid, char *key, long *val, int *size, int len);
 int grib_f_set_long_array(int *gid, char *key, long *val, int *size, int len);
+int grib_f_set_byte_array_(int* gid, char* key, unsigned char *val, int* size, int len, int lenv);
+int grib_f_set_byte_array__(int* gid, char* key, unsigned char *val, int* size, int len, int lenv);
+int grib_f_set_byte_array(int* gid, char* key, unsigned char *val, int* size, int len, int lenv);
 int grib_f_set_int_(int *gid, char *key, int *val, int len);
 int grib_f_set_int__(int *gid, char *key, int *val, int len);
 int grib_f_set_int(int *gid, char *key, int *val, int len);
@@ -209,6 +224,9 @@ int grib_f_get_real4_array(int *gid, char *key, float *val, int *size, int len);
 int grib_f_set_real4_array_(int *gid, char *key, float *val, int *size, int len);
 int grib_f_set_real4_array__(int *gid, char *key, float *val, int *size, int len);
 int grib_f_set_real4_array(int *gid, char *key, float *val, int *size, int len);
+int grib_f_set_force_real4_array_(int *gid, char *key, float *val, int *size, int len);
+int grib_f_set_force_real4_array__(int *gid, char *key, float *val, int *size, int len);
+int grib_f_set_force_real4_array(int *gid, char *key, float *val, int *size, int len);
 int grib_f_index_select_real8_(int *gid, char *key, double *val, int len);
 int grib_f_index_select_real8__(int *gid, char *key, double *val, int len);
 int grib_f_index_select_real8(int *gid, char *key, double *val, int len);
@@ -248,6 +266,9 @@ int grib_f_get_real8_array(int *gid, char *key, double *val, int *size, int len)
 int grib_f_set_real8_array_(int *gid, char *key, double *val, int *size, int len);
 int grib_f_set_real8_array__(int *gid, char *key, double *val, int *size, int len);
 int grib_f_set_real8_array(int *gid, char *key, double *val, int *size, int len);
+int grib_f_set_force_real8_array_(int *gid, char *key, double *val, int *size, int len);
+int grib_f_set_force_real8_array__(int *gid, char *key, double *val, int *size, int len);
+int grib_f_set_force_real8_array(int *gid, char *key, double *val, int *size, int len);
 int grib_f_get_string_(int *gid, char *key, char *val, int len, int len2);
 int grib_f_get_string__(int *gid, char *key, char *val, int len, int len2);
 int grib_f_get_string(int *gid, char *key, char *val, int len, int len2);
