@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2013 ECMWF.
+ * Copyright 2005-2014 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -95,31 +95,32 @@ static void init_class(grib_action_class* c)
 /* END_CLASS_IMP */
 
 grib_action* grib_action_create_if( grib_context* context,
-    grib_expression* expression,
-    grib_action* block_true,grib_action* block_false,int transient)
-{   char name[1024];
-  grib_action_if* a ;
-  grib_action_class* c   = grib_action_class_if;
-  grib_action* act       = (grib_action*)grib_context_malloc_clear_persistent(context,c->size);
-  act->op              = grib_context_strdup_persistent(context,"section");
+        grib_expression* expression,
+        grib_action* block_true,grib_action* block_false,int transient)
+{
+    char name[1024];
+    grib_action_if* a ;
+    grib_action_class* c   = grib_action_class_if;
+    grib_action* act       = (grib_action*)grib_context_malloc_clear_persistent(context,c->size);
+    act->op              = grib_context_strdup_persistent(context,"section");
 
-  act->cclass       = c;
-  a                 = (grib_action_if*)act;
-  act->context      = context;
+    act->cclass       = c;
+    a                 = (grib_action_if*)act;
+    act->context      = context;
 
-  a->expression  = expression;
-  a->block_true  = block_true;
-  a->block_false = block_false;
-  a->transient   = transient;
+    a->expression  = expression;
+    a->block_true  = block_true;
+    a->block_false = block_false;
+    a->transient   = transient;
 
-  if (transient)
-	  sprintf(name,"__if%p",(void*)a);
-  else
-	  sprintf(name,"_if%p",(void*)a);
+    if (transient)
+        sprintf(name,"__if%p",(void*)a);
+    else
+        sprintf(name,"_if%p",(void*)a);
 
-  act->name      = grib_context_strdup_persistent(context,name);
+    act->name      = grib_context_strdup_persistent(context,name);
 
-  return act;
+    return act;
 }
 
 static void compile(grib_action* act, grib_compiler *compiler)
@@ -145,157 +146,165 @@ static void compile(grib_action* act, grib_compiler *compiler)
 
 static int create_accessor( grib_section* p, grib_action* act, grib_loader *h)
 {
-  grib_action_if* a = (grib_action_if*)act;
-  grib_action* next = NULL;
-  int ret = 0;
-  long lres=0;
+    grib_action_if* a = (grib_action_if*)act;
+    grib_action* next = NULL;
+    int ret = 0;
+    long lres=0;
 
-  grib_accessor* as = NULL;
-  grib_section*  gs = NULL;
+    grib_accessor* as = NULL;
+    grib_section*  gs = NULL;
 
-  as = grib_accessor_factory(p, act,0,NULL);
-  if(!as)return GRIB_INTERNAL_ERROR;
-  gs = as->sub_section;
-  grib_push_accessor(as,p->block);
+    as = grib_accessor_factory(p, act,0,NULL);
+    if(!as)return GRIB_INTERNAL_ERROR;
+    gs = as->sub_section;
+    grib_push_accessor(as,p->block);
 
-  if ((ret=grib_expression_evaluate_long(p->h,a->expression,&lres)) != GRIB_SUCCESS)
-    return ret;
+    if ((ret=grib_expression_evaluate_long(p->h,a->expression,&lres)) != GRIB_SUCCESS)
+        return ret;
 
-  if(lres)
-    next = a->block_true;
-  else
-    next = a->block_false;
+    if(lres)
+        next = a->block_true;
+    else
+        next = a->block_false;
 
 #if 0
-if(p->h->context->debug > 1)
-{
-  printf("EVALUATE create_accessor_handle ");
-grib_expression_print(p->h->context,a->expression,p->h);
-printf(" [%d]\n", next == a->block_true);
+    if(p->h->context->debug > 1)
+    {
+        printf("EVALUATE create_accessor_handle ");
+        grib_expression_print(p->h->context,a->expression,p->h);
+        printf(" [%d]\n", next == a->block_true);
 
-  grib_dump_action_branch(stdout,next,5);
-}
+        grib_dump_action_branch(stdout,next,5);
+    }
 #endif
 
-  gs->branch = next;
-  grib_dependency_observe_expression(as,a->expression);
+    gs->branch = next;
+    grib_dependency_observe_expression(as,a->expression);
 
-  while(next){
+    while(next){
 
-    ret = grib_create_accessor(gs, next, h);
-    if(ret != GRIB_SUCCESS) return ret;
-    next= next->next;
-  }
+        ret = grib_create_accessor(gs, next, h);
+        if(ret != GRIB_SUCCESS) return ret;
+        next= next->next;
+    }
 
-  return GRIB_SUCCESS;
+    return GRIB_SUCCESS;
 }
 
 static int execute(grib_action* act, grib_handle *h)
 {
-  grib_action_if* a = (grib_action_if*)act;
-  grib_action* next = NULL;
-  int ret = 0;
-  long lres=0;
+    grib_action_if* a = (grib_action_if*)act;
+    grib_action* next = NULL;
+    int ret = 0;
+    long lres=0;
 
-  if ((ret=grib_expression_evaluate_long(h,a->expression,&lres)) != GRIB_SUCCESS) {
-    if (ret == GRIB_NOT_FOUND) lres=0;
+    /* See GRIB-394 */
+    int type = grib_expression_native_type(h, a->expression);
+    if (type != GRIB_TYPE_DOUBLE) {
+        if ((ret=grib_expression_evaluate_long(h,a->expression,&lres)) != GRIB_SUCCESS) {
+            if (ret == GRIB_NOT_FOUND) lres=0;
+            else return ret;
+        }
+    }
+    else {
+        double dres = 0.0;
+        ret = grib_expression_evaluate_double(h, a->expression, &dres);
+        lres = (long)dres;
+        if ( ret != GRIB_SUCCESS ) {
+            if (ret == GRIB_NOT_FOUND) lres=0;
+            else return ret;
+        }
+    }
+
+    if(lres)
+        next = a->block_true;
     else
-     return ret;
-  }
+        next = a->block_false;
 
-  if(lres)
-    next = a->block_true;
-  else
-    next = a->block_false;
+    while(next){
+        ret = grib_action_execute(next, h);
+        if(ret != GRIB_SUCCESS) return ret;
+        next= next->next;
+    }
 
-  while(next){
-
-    ret = grib_action_execute(next, h);
-    if(ret != GRIB_SUCCESS) return ret;
-    next= next->next;
-  }
-
-  return GRIB_SUCCESS;
+    return GRIB_SUCCESS;
 }
 
 static void dump(grib_action* act, FILE* f, int lvl)
 {
-  grib_action_if* a = (grib_action_if*)act;
-  int i = 0;
+    grib_action_if* a = (grib_action_if*)act;
+    int i = 0;
 
-  for (i=0;i<lvl;i++)
-    grib_context_print(act->context,f,"     ");
+    for (i=0;i<lvl;i++)
+        grib_context_print(act->context,f,"     ");
 
-  printf("if(%s) { ",act->name);  grib_expression_print(act->context,a->expression,0);
+    printf("if(%s) { ",act->name);  grib_expression_print(act->context,a->expression,0);
     printf("\n");
 
-  if(a->block_true){
-    /*      grib_context_print(act->context,f,"IF \t TODO \n");  TODO */
-    grib_dump_action_branch(f,a->block_true,lvl+1);
-  }
-  if(a->block_false){
-    printf("}\n");
-  for (i=0;i<lvl;i++)
-    grib_context_print(act->context,f,"     ");
-  printf("else(%s) { ",act->name);  grib_expression_print(act->context,a->expression,0);
-    /*     grib_context_print(act->context,f,"ELSE \n" );*/
-    grib_dump_action_branch(f,a->block_false,lvl+1);
-  }
-  for (i=0;i<lvl;i++)
-    grib_context_print(act->context,f,"     ");
+    if(a->block_true){
+        /*      grib_context_print(act->context,f,"IF \t TODO \n");  TODO */
+        grib_dump_action_branch(f,a->block_true,lvl+1);
+    }
+    if(a->block_false){
+        printf("}\n");
+        for (i=0;i<lvl;i++)
+            grib_context_print(act->context,f,"     ");
+        printf("else(%s) { ",act->name);  grib_expression_print(act->context,a->expression,0);
+        /*     grib_context_print(act->context,f,"ELSE \n" );*/
+        grib_dump_action_branch(f,a->block_false,lvl+1);
+    }
+    for (i=0;i<lvl;i++)
+        grib_context_print(act->context,f,"     ");
     printf("}\n");
 }
 
-
 static grib_action* reparse(grib_action* a,grib_accessor* acc,int* doit)
 {
-  int ret=0;
-  long lres=0;
-  grib_action_if* self = (grib_action_if*)a;
+    int ret=0;
+    long lres=0;
+    grib_action_if* self = (grib_action_if*)a;
 
-  /* printf("reparse %s %s\n",a->name,acc->name); */
+    /* printf("reparse %s %s\n",a->name,acc->name); */
 
-  if((ret=grib_expression_evaluate_long(acc->parent->h,self->expression,&lres)) != GRIB_SUCCESS)
-    grib_context_log(acc->parent->h->context,
-      GRIB_LOG_ERROR,"if reparse  grib_expression_evaluate_long %s",
-        grib_get_error_message(ret));
+    if((ret=grib_expression_evaluate_long(acc->parent->h,self->expression,&lres)) != GRIB_SUCCESS)
+        grib_context_log(acc->parent->h->context,
+                GRIB_LOG_ERROR,"if reparse  grib_expression_evaluate_long %s",
+                grib_get_error_message(ret));
 
-  if(lres)
-    return self->block_true;
-  else
-    return self->block_false;
+    if(lres)
+        return self->block_true;
+    else
+        return self->block_false;
 
 }
 
 static void destroy(grib_context* context,grib_action* act)
 {
-  grib_action_if* a = (grib_action_if*) act;
-  grib_action *t = a->block_true;
-  grib_action *f = a->block_false;
+    grib_action_if* a = (grib_action_if*) act;
+    grib_action *t = a->block_true;
+    grib_action *f = a->block_false;
 
-  while(t)
-  {
-    grib_action *nt = t->next;
-    grib_free_action(context,t);
-    t = nt;
-  }
+    while(t)
+    {
+        grib_action *nt = t->next;
+        grib_free_action(context,t);
+        t = nt;
+    }
 
-  while(f)
-  {
-    grib_action *nf = f->next;
-    grib_free_action(context,f);
-    f = nf;
-  }
+    while(f)
+    {
+        grib_action *nf = f->next;
+        grib_free_action(context,f);
+        f = nf;
+    }
 
 
-  grib_expression_free(context,a->expression);
+    grib_expression_free(context,a->expression);
 
-  grib_context_free_persistent(context, act->name);
-  grib_context_free_persistent(context, act->op);
+    grib_context_free_persistent(context, act->name);
+    grib_context_free_persistent(context, act->op);
 }
 
 static void xref(grib_action* d, FILE* f,const char* path)
 {
 }
-
-
