@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2013 ECMWF.
+ * Copyright 2005-2014 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -143,6 +143,7 @@ static int test_bit(long a, long b)
 {
   return a&(1<<b);
 }
+
 static int grib_get_codeflag(grib_accessor* a, long code, char* codename)
 {
   grib_accessor_codeflag* self = (grib_accessor_codeflag*)a;
@@ -157,7 +158,7 @@ static int grib_get_codeflag(grib_accessor* a, long code, char* codename)
 
   grib_recompose_name(a->parent->h,NULL, self->tablename, fname,1);
 
-  if ((filename=grib_context_full_path(a->parent->h->context,fname))==NULL) {
+  if ((filename=grib_context_full_defs_path(a->parent->h->context,fname))==NULL) {
     grib_context_log(a->parent->h->context,GRIB_LOG_WARNING,"Cannot open flag table %s",filename);
     strcpy(codename, "Cannot open flag table");
     return GRIB_FILE_NOT_FOUND;
@@ -233,6 +234,4 @@ static void dump(grib_accessor* a, grib_dumper* dumper)
 
   grib_dump_bits(dumper,a,flagname);
 
-
-
 }
