@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2013 ECMWF.
+ * Copyright 2005-2014 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -339,7 +339,6 @@ static int      spatial_difference (grib_context *c, unsigned long* vals, long
 
   long j = 3;
 
-
   long *v = grib_context_malloc(c,(len)*sizeof(long));
 
   for(j = 0; j< len;j++)
@@ -567,9 +566,6 @@ static int  unpack_double(grib_accessor* a, double* val, size_t *len)
   if(snd_bitmap || matrix_values)
     return GRIB_NOT_IMPLEMENTED;
 
-
-  sec_val  = grib_context_malloc(a->parent->h->context,(n_vals)*sizeof(unsigned long));
-  grib_context_free(a->parent->h->context,sec_val);
   sec_val  = grib_context_malloc(a->parent->h->context,(n_vals)*sizeof(unsigned long));
 
   buf_width_of_group  +=  a->offset;
@@ -729,7 +725,6 @@ static int pack_double(grib_accessor* a, const double* val, size_t *len)
   double min;
   int extraValues=0;
 
-
   size_t nv =0;
 
   if (*len ==0) return GRIB_NO_VALUES;
@@ -806,7 +801,7 @@ static int pack_double(grib_accessor* a, const double* val, size_t *len)
 
 
  /*   for(i=0;i < 10;i++)
-      printf("paking value [%d] %g %ld     %ld bias %ld <<\n", i, val[i],sec_val[i],binary_scale_factor,bias );
+      printf("packing value [%d] %g %ld     %ld bias %ld <<\n", i, val[i],sec_val[i],binary_scale_factor,bias );
 */
   nv        = n_vals-n_sp_diff;
   group_val = sec_val+n_sp_diff;
@@ -870,7 +865,7 @@ static int pack_double(grib_accessor* a, const double* val, size_t *len)
       grib_encode_unsigned_longb(buf_vals, sec_val[vcount+j]-sd->array_of_group_refs[i] ,&bitp , sd->array_of_group_width[i]);
 
         /*    if(vcount+j < 10)
-             printf(">>paking value [%ld] %g %ld     %ld nb %ld <<\n", vcount+j, val[vcount+j],sec_val[vcount+j],binary_scale_factor,sd->array_of_group_refs[i] );*/
+             printf(">>packing value [%ld] %g %ld     %ld nb %ld <<\n", vcount+j, val[vcount+j],sec_val[vcount+j],binary_scale_factor,sd->array_of_group_refs[i] );*/
             }
          vcount+= sd->array_of_group_size[i];
     }
