@@ -206,15 +206,15 @@ static unsigned long nbits[32]={
 };
 
 static long number_of_bits(unsigned long x) {
-    unsigned long *n=nbits;
-    const int count = sizeof(nbits)/sizeof(nbits[0]);
-    long i=0;
-    while (x>=*n) {
-        n++;
-        i++;
-        Assert(i<count);
+	unsigned long *n=nbits;
+   const int count = sizeof(nbits)/sizeof(nbits[0]);
+	long i=0;
+	while (x>=*n) {
+      n++;
+      i++;
+      Assert(i<count);
    }
-   return i;
+	return i;
 }
 
 static void init(grib_accessor* a,const long v, grib_arguments* args)
@@ -282,13 +282,15 @@ static int unpack_double_element(grib_accessor* a, size_t idx, double* val)
     size_t size;
     double* values;
     int err=0;
+    
+    /* GRIB-564: The index idx relates to codedValues NOT values! */
 
-    err=grib_get_size(a->parent->h,"values",&size);
+    err=grib_get_size(a->parent->h,"codedValues",&size);
     if (err) return err;
-    if (idx > size) return GRIB_INVALID_NEAREST;
+    if (idx >= size) return GRIB_INVALID_NEAREST;
 
     values=grib_context_malloc_clear(a->parent->h->context,size*sizeof(double));
-    err=grib_get_double_array(a->parent->h,"values",values,&size);
+    err=grib_get_double_array(a->parent->h,"codedValues",values,&size);
     if (err) return err;
     *val=values[idx];
     grib_context_free(a->parent->h->context,values);
@@ -593,7 +595,7 @@ static int pack_double(grib_accessor* a, const double* val, size_t *len)
 
 	long numberOfGroups;
 	long groupLengthC,groupLengthA,remainingValues,count;
-	long maxA,minA;
+	long maxA=0,minA=0;
 	long maxC,minC,offsetC;
 	long maxAC,minAC;
 	long range,bias=0,maxSPD;
