@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2013 ECMWF.
+ * Copyright 2005-2014 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -665,14 +665,14 @@ cleanup:
 static int  unpack_double(grib_accessor* a, double* val, size_t *len)
 {
   grib_context_log(a->parent->h->context, GRIB_LOG_ERROR,
-      "grib_accessor_data_png_packing : png support no enabled. Please rerun configure with --with-png-support");
+      "grib_accessor_data_png_packing: png support not enabled. Please rerun configure with --with-png-support");
   return GRIB_NOT_IMPLEMENTED;
 }
 
 static int pack_double(grib_accessor* a, const double* val, size_t *len)
 {
   grib_context_log(a->parent->h->context, GRIB_LOG_ERROR,
-      "grib_accessor_data_png_packing : png support no enabled. Please rerun configure with --with-png-support");
+      "grib_accessor_data_png_packing: png support not enabled. Please rerun configure with --with-png-support");
   return GRIB_NOT_IMPLEMENTED;
 }
 
