@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2013 ECMWF.
+ * Copyright 2005-2014 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -140,10 +140,10 @@ static void init(grib_accessor* a,const long l, grib_arguments* c)
   self->scaledValue = grib_arguments_get_name(a->parent->h,c,n++);
 
   a->flags |= GRIB_ACCESSOR_FLAG_READ_ONLY;
-
 }
 
-static int    unpack_double   (grib_accessor* a, double* val, size_t *len) {
+static int unpack_double(grib_accessor* a, double* val, size_t *len)
+{
   grib_accessor_from_scale_factor_scaled_value* self = (grib_accessor_from_scale_factor_scaled_value*)a;
   int ret = 0;
   long scaleFactor=0;
@@ -164,8 +164,8 @@ static int    unpack_double   (grib_accessor* a, double* val, size_t *len) {
   return ret;
 }
 
-
-static int is_missing(grib_accessor* a){
+static int is_missing(grib_accessor* a)
+{
   grib_accessor_from_scale_factor_scaled_value* self = (grib_accessor_from_scale_factor_scaled_value*)a;
   int ret = 0;
   long scaleFactor=0;
