@@ -1,10 +1,11 @@
-/**
- * Copyright 2005-2007 ECMWF
- * 
- * Licensed under the GNU Lesser General Public License which
- * incorporates the terms and conditions of version 3 of the GNU
- * General Public License.
- * See LICENSE and gpl-3.0.txt for details.
+/*
+ * Copyright 2005-2014 ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
+ * In applying this licence, ECMWF does not waive the privileges and immunities granted to it by
+ * virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.
  */
 
 #include "grib_api_internal.h"
@@ -69,6 +70,7 @@ static grib_accessor_class _grib_accessor_class_validity_time = {
     0,                    /* free mem                       */
     &dump,                       /* describes himself         */
     0,                /* get length of section     */
+    0,              /* get length of string      */
     0,                /* get number of values      */
     0,                 /* get number of bytes      */
     0,                /* get offset to bytes           */
@@ -93,6 +95,7 @@ static grib_accessor_class _grib_accessor_class_validity_time = {
     0,                       /* next accessor    */
     0,                    /* compare vs. another accessor   */
     0,     /* unpack only ith value          */
+    0,     /* unpack a subarray         */
     0,             		/* clear          */
 };
 
@@ -103,6 +106,7 @@ grib_accessor_class* grib_accessor_class_validity_time = &_grib_accessor_class_v
 static void init_class(grib_accessor_class* c)
 {
 	c->next_offset	=	(*(c->super))->next_offset;
+	c->string_length	=	(*(c->super))->string_length;
 	c->value_count	=	(*(c->super))->value_count;
 	c->byte_count	=	(*(c->super))->byte_count;
 	c->byte_offset	=	(*(c->super))->byte_offset;
@@ -126,23 +130,41 @@ static void init_class(grib_accessor_class* c)
 	c->next	=	(*(c->super))->next;
 	c->compare	=	(*(c->super))->compare;
 	c->unpack_double_element	=	(*(c->super))->unpack_double_element;
+	c->unpack_double_subarray	=	(*(c->super))->unpack_double_subarray;
 	c->clear	=	(*(c->super))->clear;
 }
 
 /* END_CLASS_IMP */
 
-static double u2h[] =  {
-  1 / 60.0,      /* (0) minutes */
-  1,    /* (1) hour    */
-  24,   /* (2) day     */
-  720,   /* (3) month   */
-  -1, -1, -1, -1, -1, -1,-1,
-  3,   /* (10) 3 hours */
-  6,   /* (11) 6 hours */
-  12,   /* (12) 12 hours */
-  1 /3600.0        /* (13) seconds  */
+/* Table of multipliers to convert step units to minutes */
+static double u2m[] =  {
+  1,         /* index 0:  minutes  */
+  60,        /* index 1:  hour     */
+  24*60,     /* index 2:  day      */
+  24*60*30,  /* index 3:  month    */
+  -1,        /* index 4:  year     */
+  -1,        /* index 5:  decade   */
+  -1,        /* index 6:  30 years */
+  -1,        /* index 7:  century  */
+  -1,        /* index 8:  RESERVED */
+  -1,        /* index 9:  RESERVED */
+  3*60,      /* index 10: 3 hours  */
+  6*60,      /* index 11: 6 hours  */
+  12*60,     /* index 12: 12 hours */
+  1/60.0,    /* index 13: seconds  */
+  15,        /* index 14: 15 mins  */
+  30         /* index 15: 30 mins  */
 };
 
+static long convert_to_minutes(long step, long stepUnits)
+{
+	if (stepUnits == 0) return step;    /* unit=minutes so no change */
+	if (stepUnits == 1) return step*60; /* unit=hours */
+	/* Assert( stepUnits < sizeof(u2m)/sizeof(u2m[0]) ); */
+
+	return (long) (step*u2m[stepUnits]);
+}
+
 static void init(grib_accessor* a,const long l, grib_arguments* c)
 {
 	grib_accessor_validity_time* self = (grib_accessor_validity_time*)a;
@@ -151,7 +173,7 @@ static void init(grib_accessor* a,const long l, grib_arguments* c)
 	self->date = grib_arguments_get_name(a->parent->h,c,n++);
 	self->time = grib_arguments_get_name(a->parent->h,c,n++);
 	self->step = grib_arguments_get_name(a->parent->h,c,n++);
-    self->stepUnits = grib_arguments_get_name(a->parent->h,c,n++);
+	self->stepUnits = grib_arguments_get_name(a->parent->h,c,n++);
 	self->hours = grib_arguments_get_name(a->parent->h,c,n++);
 	self->minutes = grib_arguments_get_name(a->parent->h,c,n++);
 
@@ -163,7 +185,6 @@ static void dump(grib_accessor* a, grib_dumper* dumper)
 	grib_dump_long(dumper,a,NULL);
 }
 
-
 static int unpack_long(grib_accessor* a, long* val, size_t *len)
 {   
 	grib_accessor_validity_time* self = (grib_accessor_validity_time*)a;
@@ -171,8 +192,8 @@ static int unpack_long(grib_accessor* a, long* val, size_t *len)
 	long date = 0;
 	long time = 0;
 	long step = 0;
-    long stepUnits = 0;
-    long minutes=0;
+	long stepUnits = 0;
+	long hours = 0, minutes=0, step_mins=0, tmp, tmp_hrs, tmp_mins;
 
 	if (self->hours) {
 		long hours,minutes;
@@ -185,41 +206,27 @@ static int unpack_long(grib_accessor* a, long* val, size_t *len)
 	if ((ret=grib_get_long_internal(a->parent->h, self->time,&time))!=GRIB_SUCCESS) return ret;
 	if ((ret=grib_get_long_internal(a->parent->h, self->step,&step))!=GRIB_SUCCESS) return ret;
 
-    if (self->stepUnits) {
-      if ((ret=grib_get_long_internal(a->parent->h, self->stepUnits,&stepUnits))!=GRIB_SUCCESS) return ret;
-
-      switch (stepUnits) {
-        case 0:
-          step/=60;
-          break;
-        case 13:
-          step/=3600;
-          break;
-        default:
-          step*=u2h[stepUnits];
-      }
-
-    }
-
-    minutes = time % 100;
-	time /= 100;
-	time += step;
-
-	date = grib_date_to_julian (date);
-	while(time>=24) {
-		date ++;
-		time -= 24;
+	/* Seconds will always be zero. So convert to minutes */
+	if (self->stepUnits) {
+		if ((ret=grib_get_long_internal(a->parent->h, self->stepUnits,&stepUnits))!=GRIB_SUCCESS) return ret;
+		step_mins = convert_to_minutes(step, stepUnits);
+		Assert(step_mins>=0);
 	}
 
-
-	/* printf("\n********\n date %d, time %d, step %d, vdate: %d, cdate %d, vd %d\n********\n", date, time, step, vdate, cdate, vd);    */
+	minutes = time % 100;
+	hours = time / 100;
+	tmp = minutes + step_mins; /* add the step to our minutes */
+	tmp_hrs = tmp/60;          /* how many hours and mins is that? */
+	tmp_mins = tmp%60;
+	hours += tmp_hrs;          /* increment hours */
+	hours = hours % 24;        /* wrap round if >= 24 */
+	time = hours * 100 + tmp_mins;
 
 	if(*len < 1)
 		return GRIB_ARRAY_TOO_SMALL;
 
-	*val   = time * 100+ minutes;
+	*val = time;
 
-	/* fprintf(stdout,"\n********\n %d cdate %d vd %d\n********\n", vdate, cdate, step); */
 	return GRIB_SUCCESS;
 }
 
