@@ -1,11 +1,12 @@
-/**
-* Copyright 2005-2007 ECMWF
-*
-* Licensed under the GNU Lesser General Public License which
-* incorporates the terms and conditions of version 3 of the GNU
-* General Public License.
-* See LICENSE and gpl-3.0.txt for details.
-*/
+/*
+ * Copyright 2005-2014 ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
+ * In applying this licence, ECMWF does not waive the privileges and immunities granted to it by
+ * virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.
+ */
 
 /**
     include private headers used for all internal functions of
@@ -20,6 +21,12 @@
 extern "C" {
 #endif
 
+/* cmake config header */
+#ifdef HAVE_GRIB_API_CONFIG_H 
+#include "grib_api_config.h"
+#endif
+
+/* autoconf config header */
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #ifdef _LARGE_FILES
@@ -57,7 +64,6 @@ extern "C" {
 #include <errno.h>
 #include <stdarg.h>
 #include <stdlib.h>
-#include <math.h>
 #include <ctype.h>
 #include <inttypes.h>
 
@@ -69,25 +75,32 @@ extern "C" {
 
 
 #if GRIB_LINUX_PTHREADS
-#define PTHREAD_MUTEX_RECURSIVE PTHREAD_MUTEX_RECURSIVE_NP
-extern int pthread_mutexattr_settype(pthread_mutexattr_t* attr,int type);
+ extern int pthread_mutexattr_settype(pthread_mutexattr_t* attr,int type);
 #endif
 
 #if GRIB_PTHREADS
-
-#include <pthread.h>
-#define GRIB_PTHREAD_ONCE(a,b) pthread_once(a,b);
-#define GRIB_MUTEX_LOCK(a) pthread_mutex_lock(a);
-#define GRIB_MUTEX_UNLOCK(a) pthread_mutex_unlock(a);
-
+ #include <pthread.h>
+ #define GRIB_PTHREAD_ONCE(a,b) pthread_once(a,b);
+ #define GRIB_MUTEX_LOCK(a) pthread_mutex_lock(a); 
+ #define GRIB_MUTEX_UNLOCK(a) pthread_mutex_unlock(a);
+/*
+#define GRIB_MUTEX_LOCK(a) {pthread_mutex_lock(a); printf("MUTEX LOCK %p %s line %d\n",(void*)a,__FILE__,__LINE__);}
+#define GRIB_MUTEX_UNLOCK(a) {pthread_mutex_unlock(a);printf("MUTEX UNLOCK %p %s line %d\n",(void*)a,__FILE__,__LINE__);} 
+*/
 #else
-
-#define GRIB_PTHREAD_ONCE(a,b)
-#define GRIB_MUTEX_LOCK(a)
-#define GRIB_MUTEX_UNLOCK(a)
-
+ #define GRIB_PTHREAD_ONCE(a,b)
+ #define GRIB_MUTEX_LOCK(a)
+ #define GRIB_MUTEX_UNLOCK(a)
 #endif
 
+#if GRIB_LINUX_PTHREADS
+ /* Note: in newer pthreads PTHREAD_MUTEX_RECURSIVE and PTHREAD_MUTEX_RECURSIVE_NP are enums */
+ #if !defined (PTHREAD_MUTEX_RECURSIVE)
+  #define PTHREAD_MUTEX_RECURSIVE PTHREAD_MUTEX_RECURSIVE_NP
+ #endif
+#endif
+
+
 #ifndef HAVE_FSEEKO
 #define fseeko fseek
 #define ftello ftell
@@ -95,6 +108,12 @@ extern int pthread_mutexattr_settype(pthread_mutexattr_t* attr,int type);
 
 #define Assert(a) {if(!(a)) grib_fail(#a,__FILE__,__LINE__);}
 
+/* Compile time assertion - Thanks to Ralf Holly */
+#define COMPILE_TIME_ASSERT(e) \
+   do { \
+       enum { assert_static__ = 1/(e) }; \
+      } while (0)
+
 #include "grib_api.h"
 
 #define GRIB_UNKNOWN_VALUE   -9999.999
@@ -206,6 +225,7 @@ typedef  int   (*accessor_clear_proc)           (grib_accessor*);
 typedef  void  (*accessor_init_class_proc)               (grib_accessor_class*);
 
 typedef  int   (*accessor_compare_proc)                  (grib_accessor*, grib_accessor*);
+typedef  size_t  (*accessor_string_proc)                    (grib_accessor*);
 typedef  long  (*accessor_value_proc)                    (grib_accessor*);
 typedef  void  (*accessor_dump_proc)                     (grib_accessor*, grib_dumper*);
 typedef  void  (*accessor_init_proc)                     (grib_accessor*, const long len, grib_arguments*);
@@ -669,6 +689,7 @@ struct grib_accessor_class
     accessor_dump_proc              dump;
     accessor_value_proc             next_offset;
 
+    accessor_string_proc            string_length;
     accessor_value_proc             value_count;
 
     accessor_value_proc             byte_count;
@@ -757,8 +778,11 @@ struct grib_context
     int                             write_on_fail;
     int                             no_abort;
 	int 							io_buffer_size;
+	int 							no_big_group_split;
+	int 							no_spd;
+	int 							keep_matrix;
     char*                           grib_definition_files_path;
-    char*                           grib_templates_path;
+    char*                           grib_samples_path;
     char*                           grib_concept_path;
 
     grib_action_file_list*          grib_reader;
@@ -796,6 +820,7 @@ struct grib_context
     int                             no_fail_on_wrong_length;
     int                             gts_header_on;
     int                             gribex_mode_on;
+    int                             large_constant_fields;
     grib_itrie*                     keys;
     int                             keys_count;
     grib_itrie*                     concepts_index;
@@ -805,6 +830,7 @@ struct grib_context
     
     grib_string_list*                blacklist;
     int                             ieee_packing;
+	FILE*                           log_stream;
 	grib_trie*                      classes;
 #if GRIB_PTHREADS
     pthread_mutex_t                 mutex;
@@ -813,7 +839,7 @@ struct grib_context
 };
 
 /* file_pool */
-grib_string_list grib_file_not_found;
+extern grib_string_list grib_file_not_found;
 
 typedef struct grib_file grib_file;
 typedef struct grib_file_pool grib_file_pool;
@@ -928,6 +954,39 @@ struct grib_fieldset {
 };
 #endif
 
+/* concept index structures */
+
+typedef struct grib_concept_index_key grib_concept_index_key;
+typedef struct grib_concept_index grib_concept_index;
+typedef struct grib_conditions_tree grib_conditions_tree;
+typedef struct grib_concept_entry grib_concept_entry;
+typedef struct grib_concept_key grib_concept_key;
+
+struct grib_concept_index_entry {
+  char* 	name;
+  char*		value;
+  int type;
+  grib_concept_entry* next;
+};
+
+struct grib_concept_index_key {
+  char* 	name;
+  int type;
+  grib_concept_key* next;
+};
+
+struct grib_concept_index {
+	grib_context* context;
+	grib_concept_key* keys;
+	grib_conditions_tree* conditions;
+};
+
+struct grib_conditions_tree {
+	char*   value;
+	void* 	object;
+	grib_conditions_tree* next;
+	grib_conditions_tree* next_key;
+};
 
 /* index structures */
 
