@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2013 ECMWF.
+ * Copyright 2005-2014 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -103,6 +103,21 @@ static int evaluate_long(grib_expression *g,grib_handle* h,long* lres)
   int ret;
   grib_expression_binop* e = (grib_expression_binop*)g;
 
+#if 0 /* DEBUGGING */
+    {
+        int typeLeft, typeRight;
+        const char* nameLeft;
+        const char* nameRight;
+        typeLeft = grib_expression_native_type(h, e->left);
+        typeRight = grib_expression_native_type(h, e->right);
+        nameLeft = grib_expression_get_name(e->left);
+        nameRight= grib_expression_get_name(e->right);
+        printf("eval_long nameLeft=%s (type=%d), nameRight=%s (type=%d)\n",nameLeft,typeLeft, nameRight,typeRight);
+        grib_expression_print(h->context, g, h);
+        printf("\n");
+    }
+#endif
+
   ret = grib_expression_evaluate_long(h,e->left,&v1);
   if (ret != GRIB_SUCCESS) return ret;
 
@@ -121,6 +136,21 @@ static int evaluate_double(grib_expression *g,grib_handle* h,double* dres)
 
   grib_expression_binop* e = (grib_expression_binop*)g;
 
+#if 0 /* DEBUGGING */
+    {
+        int typeLeft, typeRight;
+        const char* nameLeft;
+        const char* nameRight;
+        typeLeft = grib_expression_native_type(h, e->left);
+        typeRight = grib_expression_native_type(h, e->right);
+        nameLeft = grib_expression_get_name(e->left);
+        nameRight= grib_expression_get_name(e->right);
+        printf("eval_dbl nameLeft=%s (type=%d), nameRight=%s (type=%d)\n",nameLeft,typeLeft, nameRight,typeRight);
+        grib_expression_print(h->context, g, h);
+        printf("\n");
+    }
+#endif
+
   ret = grib_expression_evaluate_double(h,e->left,&v1);
   if (ret != GRIB_SUCCESS) return ret;
 
@@ -130,7 +160,6 @@ static int evaluate_double(grib_expression *g,grib_handle* h,double* dres)
   *dres = e->double_func ? e->double_func(v1,v2) : e->long_func(v1,v2);
 
   return GRIB_SUCCESS;
-
 }
 
 static void print(grib_context* c,grib_expression* g,grib_handle* f)
@@ -150,8 +179,8 @@ static void destroy(grib_context* c,grib_expression* g)
   grib_expression_free(c,e->right);
 }
 
-
-static void  add_dependency(grib_expression* g, grib_accessor* observer){
+static void  add_dependency(grib_expression* g, grib_accessor* observer)
+{
   grib_expression_binop* e = (grib_expression_binop*)g;
   grib_dependency_observe_expression(observer,e->left);
   grib_dependency_observe_expression(observer,e->right);
@@ -186,5 +215,11 @@ static void compile(grib_expression* g,grib_compiler* c)
 static int native_type(grib_expression* g,grib_handle *h)
 {
   grib_expression_binop* e = (grib_expression_binop*)g;
-  return e->double_func ? GRIB_TYPE_LONG : GRIB_TYPE_DOUBLE;
+    /* See GRIB-394 : The type of this binary expression will be double if any of its operands are double */
+    if (grib_expression_native_type(h, e->left)  == GRIB_TYPE_DOUBLE ||
+            grib_expression_native_type(h, e->right) == GRIB_TYPE_DOUBLE)
+    {
+        return GRIB_TYPE_DOUBLE;
+    }
+    return e->long_func ? GRIB_TYPE_LONG : GRIB_TYPE_DOUBLE;
 }
