@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2013 ECMWF.
+ * Copyright 2005-2014 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -161,6 +161,5 @@ static void compile(grib_expression* g,grib_compiler* c)
 static int native_type(grib_expression* g,grib_handle *h)
 {
 	grib_expression_unop* e = (grib_expression_unop*)g;
-	return e->double_func ? GRIB_TYPE_LONG : GRIB_TYPE_DOUBLE;
+    return e->long_func ? GRIB_TYPE_LONG : GRIB_TYPE_DOUBLE;
 }
-
