@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2013 ECMWF.
+ * Copyright 2005-2014 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -124,7 +124,6 @@ cleanup:
 	return err;
 }
 
-
 int grib_openjpeg_decode(grib_context *c, unsigned char *buf, size_t *buflen, double *val, size_t *n_vals) {
 
 	int err = GRIB_SUCCESS;
@@ -206,13 +205,13 @@ cleanup:
 
 int grib_openjpeg_decode(grib_context *c, unsigned char *buf, size_t *buflen, double *val, size_t *n_vals) {
 	grib_context_log(c, GRIB_LOG_ERROR,
-			"grib_accessor_data_jpeg2000_packing : openjpeg jpeg support not enabled. Please rerun configure with --with-openjpeg-support");
+			"grib_accessor_data_jpeg2000_packing: openjpeg jpeg support not enabled. Please rerun configure with --with-openjpeg");
 	return GRIB_NOT_IMPLEMENTED;
 }
 
 int grib_openjpeg_encode(grib_context *c, j2k_encode_helper *helper) {
 	grib_context_log(c, GRIB_LOG_ERROR,
-			"grib_accessor_data_jpeg2000_packing : openjpeg jpeg support not enabled. Please rerun configure with --with-openjpeg-support");
+			"grib_accessor_data_jpeg2000_packing: openjpeg jpeg support not enabled. Please rerun configure with --with-openjpeg");
 	return GRIB_NOT_IMPLEMENTED;
 }
 
