@@ -3,7 +3,7 @@
 #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-#
+# 
 # In applying this licence, ECMWF does not waive the privileges and immunities granted to it by
 # virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.
 #
@@ -14,4 +14,5 @@
 REDIRECT=/dev/null
 
 ${tools_dir}grib_ls ${data_dir}/budg > $REDIRECT
+${tools_dir}grib_dump ${data_dir}/budg > $REDIRECT
 
