@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright 2005-2013 ECMWF.
+# Copyright 2005-2014 ECMWF.
 #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -29,3 +29,10 @@ diff index.out ${data_dir}/index.ok
 
 rm -f index.out
 
+# test grib_index_build
+#
+tempIndex=temp.$$.ix
+${tools_dir}grib_index_build -o $tempIndex ${infile} >/dev/null
+${tools_dir}grib_dump -D ${tempIndex} > /dev/null
+
+rm -f $tempIndex
