@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2013 ECMWF.
+ * Copyright 2005-2014 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -32,9 +32,10 @@ grib_option grib_options[]={
     {"S",0,0,1,0,0},
     {"g",0,0,0,1,0},
     {"G",0,0,0,1,0},
-	{"T:",0,0,0,1,0},
+    {"T:",0,0,0,1,0},
     {"7",0,0,0,1,0},
     {"v",0,0,1,0,0},
+    {"X:",0,0,0,1,0},
     {"i:",0,0,0,1,0}
 };
 
@@ -50,19 +51,24 @@ double lon=0;
 int mode=0;
 grib_nearest* n=NULL;
 
-int main(int argc, char *argv[]) { return grib_tool(argc,argv);}
+int main(int argc, char *argv[])
+{
+    return grib_tool(argc,argv);
+}
 
-int grib_tool_before_getopt(grib_runtime_options* options) {
+int grib_tool_before_getopt(grib_runtime_options* options)
+{
   options->print_keys_count=-1;
   return 0;
 }
 
-int grib_tool_init(grib_runtime_options* options) {
+int grib_tool_init(grib_runtime_options* options)
+{
   char  *theEnd = NULL, *end1=NULL;
   size_t size=4;
   int ret=0;
   double min=0,max=0;
-  int i=0,idx=0;
+  int i=0;
   char* p=NULL;
   
   options->print_header=0;
@@ -99,8 +105,6 @@ int grib_tool_init(grib_runtime_options* options) {
         options->latlon_mask=strdup(p);
       }
     }
-
-
   }
 
   if (options->latlon && options->latlon_mask) {
@@ -125,7 +129,7 @@ int grib_tool_init(grib_runtime_options* options) {
     options->latlon_idx=-1;
     max=options->distances[0];
     for (i=0;i<4;i++)
-      if (max<options->distances[i]) {max=options->distances[i];idx=i;}
+      if (max<options->distances[i]) {max=options->distances[i];}
     min=max;
     for (i=0;i<4;i++) {
       if ((min >= options->distances[i]) && (options->mask_values[i] >= 0.5)) {
@@ -147,16 +151,19 @@ int grib_tool_init(grib_runtime_options* options) {
   
   return 0;
 }
-int grib_tool_new_filename_action(grib_runtime_options* options,const char* file) {
-   return 0;
-   }
 
-
-int grib_tool_new_file_action(grib_runtime_options* options,grib_tools_file* file) {
+int grib_tool_new_filename_action(grib_runtime_options* options,const char* file)
+{
    return 0;
 }
 
-int grib_tool_new_handle_action(grib_runtime_options* options,grib_handle* h) {
+int grib_tool_new_file_action(grib_runtime_options* options,grib_tools_file* file)
+{
+   return 0;
+}
+
+int grib_tool_new_handle_action(grib_runtime_options* options,grib_handle* h)
+{
   size_t size=4;
   int err = 0;
 
@@ -186,23 +193,24 @@ int grib_tool_new_handle_action(grib_runtime_options* options,grib_handle* h) {
 			options->latlon_idx=i;
 		}
 	}
-
   }
   
   return 0;
 }
 
-int grib_tool_skip_handle(grib_runtime_options* options, grib_handle* h) {
+int grib_tool_skip_handle(grib_runtime_options* options, grib_handle* h)
+{
   grib_handle_delete(h);
   return 0;
 }
 
-void grib_tool_print_key_values(grib_runtime_options* options,grib_handle* h) {
+void grib_tool_print_key_values(grib_runtime_options* options,grib_handle* h)
+{
   grib_print_key_values(options,h);
 }
 
-int grib_tool_finalise_action(grib_runtime_options* options) {
-
+int grib_tool_finalise_action(grib_runtime_options* options)
+{
   if (n) grib_nearest_delete(n);
   
   return 0;
