@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2013 ECMWF.
+ * Copyright 2005-2014 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -24,7 +24,8 @@ void usage( char*);
 #define INFO_PRINT_DEFINITION_PATH   (1<<1)
 #define INFO_PRINT_SAMPLES_PATH     (1<<2)
 
-int main( int argc,char* argv[]) {
+int main( int argc,char* argv[])
+{
   char* path=NULL;
   int c=0;
   int nfiles=0;
@@ -65,8 +66,9 @@ int main( int argc,char* argv[]) {
     if (GRIB_API_MAJOR_VERSION < 1) printf(" PRE-RELEASE");
     printf("\n");
     printf("\n");
-
-
+#if GRIB_PTHREADS
+        grib_context_log(grib_context_get_default(), GRIB_LOG_DEBUG, "PTHREADS enabled");
+#endif
     if ((path=getenv("GRIB_DEFINITION_PATH")) != NULL) {
       printf("Definition files path from environment variable");
       printf(" GRIB_DEFINITION_PATH=%s\n",path);
@@ -109,8 +111,6 @@ int main( int argc,char* argv[]) {
   return 0;
 }
 
-
-
 void usage(char* progname) {
   printf("\nUsage: %s [-v] [-d] [-t]\n",progname);
   exit(1);
